@@ -16,13 +16,15 @@
 #' @examples
 #'
 #' data(testdata)
+#' \dontrun{
+#' # dontrun because Examples with CPU time > 2.5 times elapsed time
 #' sdc <- createSdcObj(testdata,
 #'   keyVars=c('urbrur','roof','walls','relat','sex'),
 #'   pramVars=c('water','electcon'),
 #'   numVars=c('expend','income','savings'), w='sampling_weight')
 #' sdc <- kAnon(sdc, k=5)
 #' plot(sdc, type="ls")
-#'
+#' }
 plot.sdcMicroObj <- function(x, type="ls", ...) {
   if (!type %in% c("ls")) {
     stop("unsupported plot-type for sdcMicroObj!\n")
@@ -36,4 +38,8 @@ plot.sdcMicroObj <- function(x, type="ls", ...) {
       invisible(NULL)
     }
   }
+  if(type == "indiv_risk" | type == "indivRisk" | type == "indivrisk"){
+    irisk <- x@risk$individual[, 1]
+    
+  }
 }
